function OF = OF_output_const_alt_changing_att(x, p, OFv, Dv)
% function OF = OF_output_const_alt_changing_att(x, p, OFv, Dv)
%
% Calculate the optic flow measurements.
% - x: 3D state
% - p: rate
% - OFv, Dv: noise added to the ventral flow and divergence measurements
%
% - OF: (1) ventral flow, (2) divergence.
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

% get state variables:
v = x(1);phi = x(2); z = x(3);

% determine optic flow:
OF =     [-v*cos(phi)*cos(phi)/z + p + OFv;
    (-v*sin(2*phi)/(2*z)) + Dv];
