function OF = OF_output_const_alt_changing_att_insect(x, p, OFv, Dv)
% function OF = OF_output_const_alt_changing_att_insect(x, p, OFv, Dv)
%
% Calculate the optic flow measurements.
% - x: 4D state
% - p: rate head
% - OFv, Dv: noise added to the ventral flow and divergence measurements
%
% - OF: (1) ventral flow, (2) divergence.
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

% get state variables:
v = x(1);theta = x(2); theta_wings = x(3); z = x(4);

% determine optic flow:
OF =     [-v*cos(theta)*cos(theta)/z + p + OFv;
    (-v*sin(2*theta)/(2*z)) + Dv];
