function OF = OF_output_const_alt_changing_att_moment(x, OFv, Dv)
% function OF = OF_output_const_alt_changing_att_moment(x, OFv, Dv)
%
% Function to calculate optic flow measurements.
% - x: State (4-dimensional)
% - OFv, Dv: numbers that will be added as noise to the ideal optic flow measurements. 
%
% - OF: 2D vector with (1) ventral translational flow and (2) optic flow
% divergence.
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

% Get state variables:
v = x(1);theta = x(2); p = x(3); z = x(4);

% Output optic flow measurements:
OF = [-v*cos(theta)*cos(theta)/z + p + OFv;
      (-v*sin(2*theta)/(2*z)) + Dv];
