function analyze_robotic_experiments()
% function analyze_robotic_experiments()
%
% Runs all scripts related to the analysis of robotic experimetns in the article below. 
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Guido de Croon | g.c.h.e.decroon@tudelft.nl
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com

data_dir = '../'; 

% FIG 2:
fprintf('\nSingle flight, figure 2.\n')
filename = [data_dir 'Quadrotor_experiments/22_04_11__11_12_45.data'];
PLOT_THETA = true;
COMPARE_HISTOGRAMS = false; 
DETERMINE_ERRORS = false;
PLOT_OPTITRACK = false;
start_time = 420; end_time = 470;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, [], [], 'Single flight');

% Statistics:
filename = [data_dir 'Quadrotor_experiments/22_04_11__11_27_14.data'];
fprintf('\nStatistics 10 flights.\n');
PLOT_THETA = true;
COMPARE_HISTOGRAMS = true; 
DETERMINE_ERRORS = true;
PLOT_OPTITRACK = false;
FLIP_VX = true;
COMPARE_PHI = false;
start_time = []; end_time = [];
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, FLIP_VX, COMPARE_PHI, 'Pitch, 10 flights');
COMPARE_PHI = true;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, FLIP_VX, COMPARE_PHI, 'Roll, 10 flights');

% Plot graph for the flapper experiment:
fprintf('\nFlapper experiment, figure 3.\n')
file_name = [data_dir 'Flapper_experiments/log02_in_control.csv'];
interval = [425, 430];
plot_flight_flapper(file_name, interval);

% EXTENDED DATA FIGURES

% moving slope:
fprintf('\nMoving slope.\n')
filename = [data_dir 'Quadrotor_experiments/22_04_11__14_54_52.data'];
PLOT_THETA = true;
COMPARE_HISTOGRAMS = false; 
DETERMINE_ERRORS = false;
PLOT_OPTITRACK = false;
FLIP_VX = true;
COMPARE_PHI = false;
start_time = 100; end_time = 130;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, FLIP_VX, COMPARE_PHI, 'Moving slope');

% 3D structure:
fprintf('\n3D structure.\n');
filename = [data_dir 'Quadrotor_experiments/22_04_11__15_09_07.data'];
PLOT_THETA = true;
COMPARE_HISTOGRAMS = false; 
DETERMINE_ERRORS = false;
start_time = 70; end_time = 100;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, [], [], [], '3D structure');

% Disturbances:
fprintf('\nDisturbances.\n');
filename = [data_dir 'Quadrotor_experiments/22_04_19__11_32_35.data'];
PLOT_THETA = true;
COMPARE_HISTOGRAMS = false; 
DETERMINE_ERRORS = false;
PLOT_OPTITRACK = false;
start_time = 105; end_time = 165;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, [], [], 'Disturbances');

% Height changes, thrust bias:
fprintf('\nHeight changes with thrust bias.\n');
filename = [data_dir 'Quadrotor_experiments/22_04_19__10_13_34.data'];
PLOT_THETA = true;
COMPARE_HISTOGRAMS = false; 
DETERMINE_ERRORS = false;
PLOT_OPTITRACK = false;
FLIP_VX = false;
start_time = 150; end_time = 350;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, FLIP_VX, [], 'Height changes with thrust bias');

% Height changes with a constant height model:
fprintf('\nHeight changes with constant height model.\n');
filename = [data_dir 'Quadrotor_experiments/22_04_19__10_04_08.data'];
PLOT_THETA = true;
COMPARE_HISTOGRAMS = false; 
DETERMINE_ERRORS = false;
PLOT_OPTITRACK = false;
FLIP_VX = false;
start_time = 100; end_time = 325;
plot_attitude_experiment(filename, start_time, end_time, COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, PLOT_OPTITRACK, FLIP_VX, [], 'Height changes with constant height model');

% Statistics from 13 flights on roll angle:
fprintf('\nStatistics roll angle 13 flights.\n');
filename = [data_dir 'Quadrotor_experiments/21_11_03__14_30_07.data'];
COMPARE_HISTOGRAMS = true; DETERMINE_ERRORS = true; PLOT_THETA = false; 
plot_name = '13 flights';
plot_attitude_experiment(filename, [], [], COMPARE_HISTOGRAMS, DETERMINE_ERRORS, PLOT_THETA, [], [], [], plot_name);
