function data = get_bee_data()
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Franck Ruffier | franck.ruffier@univ-amu.fr
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

load('../Bee_data/doublefusele_1_21_recrop_20100219.mat'); 

% Put the bee data in bins depending on the velocity:
 indice_bin_0_8m_sec{21}=[];
 indice_bin_0_7m_sec{21}=[];
 indice_bin_0_6m_sec{21}=[];
 indice_bin_0_5m_sec{21}=[];
 indice_bin_0_4m_sec{21}=[];
 indice_bin_0_3m_sec{21}=[];
 indice_bin_0_2m_sec{21}=[];
 indice_bin_0_1m_sec{21}=[];

bee_nb=1;
for bee_nb=1:21
    for j=1:1:length(Manip(6).Abeille(bee_nb).Xc/10)-1
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.05 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.15
            indice_bin_0_1m_sec{bee_nb}=[indice_bin_0_1m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.15 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.25
            indice_bin_0_2m_sec{bee_nb}=[indice_bin_0_2m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.25 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.35
            indice_bin_0_3m_sec{bee_nb}=[indice_bin_0_3m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.35 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.45
            indice_bin_0_4m_sec{bee_nb}=[indice_bin_0_4m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.45 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.55
            indice_bin_0_5m_sec{bee_nb}=[indice_bin_0_5m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.55 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.65
            indice_bin_0_6m_sec{bee_nb}=[indice_bin_0_6m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.65 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.75
            indice_bin_0_7m_sec{bee_nb}=[indice_bin_0_7m_sec{bee_nb}, j];
        end
        if Manip(6).Abeille(bee_nb).Vx(j)/1000  > 0.75 && Manip(6).Abeille(bee_nb).Vx(j)/1000 < 0.85
            indice_bin_0_8m_sec{bee_nb}=[indice_bin_0_8m_sec{bee_nb}, j];
        end
    end
end
bee_nb=1;
bin_0_1m_sec=[];
bin_0_2m_sec=[];
bin_0_3m_sec=[];
bin_0_4m_sec=[];
bin_0_5m_sec=[];
bin_0_6m_sec=[];
bin_0_7m_sec=[];
bin_0_8m_sec=[];

for bee_nb=1:21
    bin_0_1m_sec=[bin_0_1m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_1m_sec{bee_nb})];
    bin_0_2m_sec=[bin_0_2m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_2m_sec{bee_nb})];
    bin_0_3m_sec=[bin_0_3m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_3m_sec{bee_nb})];
    bin_0_4m_sec=[bin_0_4m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_4m_sec{bee_nb})];
    bin_0_5m_sec=[bin_0_5m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_5m_sec{bee_nb})];
    bin_0_6m_sec=[bin_0_6m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_6m_sec{bee_nb})];
    bin_0_7m_sec=[bin_0_7m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_7m_sec{bee_nb})];
    bin_0_8m_sec=[bin_0_8m_sec Manip(6).Abeille(bee_nb).theta(indice_bin_0_8m_sec{bee_nb})];
end

% get the color palette:
color = get_color_palette();
fs = 10;
font_name = 'Times';

% Plot histograms of the data with outliers:
f1=figure('Name','Data with outliers','NumberTitle','off'); % Histogram of Raw Pitch
set(gcf, 'Color', [1 1 1]);
subplot(3,3,1)
histogram(bin_0_1m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.1m/s bin: ',num2str(var(bin_0_1m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,2)
histogram(bin_0_2m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.2m/s bin: ',num2str(var(bin_0_2m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,3)
histogram(bin_0_3m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.3m/s bin: ',num2str(var(bin_0_3m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,4)
histogram(bin_0_4m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.4m/s bin: ',num2str(var(bin_0_4m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,5)
histogram(bin_0_5m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.5m/s bin: ',num2str(var(bin_0_5m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,6)
histogram(bin_0_6m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.6m/s bin: ',num2str(var(bin_0_6m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,7)
histogram(bin_0_7m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.7m/s bin: ',num2str(var(bin_0_7m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,8)
histogram(bin_0_8m_sec,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.8m/s bin: ',num2str(var(bin_0_8m_sec,'omitnan'),3)]); xlim([-14 100]); xlabel('Pitch deg')
set(findall(gcf,'-property','FontSize'),'FontSize',fs, 'FontName', font_name)

% Remove outliers, keeping track of the number of removed samples:
n_removed = 0;
n_samples = 0;
bin_0_1m_sec_without_outlier=rmoutliers(bin_0_1m_sec);
n_samples = n_samples + length(bin_0_1m_sec);
n_removed = n_removed + length(bin_0_1m_sec) - length(bin_0_1m_sec_without_outlier);
bin_0_2m_sec_without_outlier=rmoutliers(bin_0_2m_sec);
n_samples = n_samples + length(bin_0_2m_sec);
n_removed = n_removed + length(bin_0_2m_sec) - length(bin_0_2m_sec_without_outlier);
bin_0_3m_sec_without_outlier=rmoutliers(bin_0_3m_sec);
n_samples = n_samples + length(bin_0_3m_sec);
n_removed = n_removed + length(bin_0_3m_sec) - length(bin_0_3m_sec_without_outlier);
bin_0_4m_sec_without_outlier=rmoutliers(bin_0_4m_sec);
n_samples = n_samples + length(bin_0_4m_sec);
n_removed = n_removed + length(bin_0_4m_sec) - length(bin_0_4m_sec_without_outlier);
bin_0_5m_sec_without_outlier=rmoutliers(bin_0_5m_sec);
n_samples = n_samples + length(bin_0_5m_sec);
n_removed = n_removed + length(bin_0_5m_sec) - length(bin_0_5m_sec_without_outlier);
bin_0_6m_sec_without_outlier=rmoutliers(bin_0_6m_sec);
n_samples = n_samples + length(bin_0_6m_sec);
n_removed = n_removed + length(bin_0_6m_sec) - length(bin_0_6m_sec_without_outlier);
bin_0_7m_sec_without_outlier=rmoutliers(bin_0_7m_sec);
n_samples = n_samples + length(bin_0_7m_sec);
n_removed = n_removed + length(bin_0_7m_sec) - length(bin_0_7m_sec_without_outlier);
bin_0_8m_sec_without_outlier=rmoutliers(bin_0_8m_sec);
n_samples = n_samples + length(bin_0_8m_sec);
n_removed = n_removed + length(bin_0_8m_sec) - length(bin_0_8m_sec_without_outlier);
fprintf('Initial samples = %d, final samples = %d. Total removed points = %d.\n', n_samples, n_samples - n_removed, n_removed);

% Plot histograms of the data without outliers:
f2=figure('Name','Data without outliers','NumberTitle','off'); 
set(gcf, 'Color', [1 1 1]);
subplot(3,3,1)
histogram(bin_0_1m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.1m/s bin: ',num2str(var(bin_0_1m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,2)
histogram(bin_0_2m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.2m/s bin: ',num2str(var(bin_0_2m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,3)
histogram(bin_0_3m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.3m/s bin: ',num2str(var(bin_0_3m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,4)
histogram(bin_0_4m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.4m/s bin: ',num2str(var(bin_0_4m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,5)
histogram(bin_0_5m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.5m/s bin: ',num2str(var(bin_0_5m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,6)
histogram(bin_0_6m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.6m/s bin: ',num2str(var(bin_0_6m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,7)
histogram(bin_0_7m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.7m/s bin: ',num2str(var(bin_0_7m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
subplot(3,3,8)
histogram(bin_0_8m_sec_without_outlier,[-14:6:100], 'FaceColor', color.std_theta_bee); title(['var. of 0.8m/s bin: ',num2str(var(bin_0_8m_sec_without_outlier,'omitnan'),3)]);xlim([-14 100]); xlabel('Pitch deg')
set(findall(gcf,'-property','FontSize'),'FontSize',fs, 'FontName', font_name)

% store the information in a data structure:
data.with_outliers = cell(8,1);
data.with_outliers{1} = bin_0_1m_sec;
data.with_outliers{2} = bin_0_2m_sec;
data.with_outliers{3} = bin_0_3m_sec;
data.with_outliers{4} = bin_0_4m_sec;
data.with_outliers{5} = bin_0_5m_sec;
data.with_outliers{6} = bin_0_6m_sec;
data.with_outliers{7} = bin_0_7m_sec;
data.with_outliers{8} = bin_0_8m_sec;

data.all = cell(8,1);
data.all{1} = bin_0_1m_sec_without_outlier;
data.all{2} = bin_0_2m_sec_without_outlier;
data.all{3} = bin_0_3m_sec_without_outlier;
data.all{4} = bin_0_4m_sec_without_outlier;
data.all{5} = bin_0_5m_sec_without_outlier;
data.all{6} = bin_0_6m_sec_without_outlier;
data.all{7} = bin_0_7m_sec_without_outlier;
data.all{8} = bin_0_8m_sec_without_outlier;

% determine the mean and standard deviation of theta:
data.std_theta = zeros(8, 1);
data.mn_theta = zeros(8, 1);
data.std_theta_with_outliers = zeros(8, 1);
data.mn_theta_with_outliers = zeros(8, 1);
for c = 1:8
    data.std_theta(c) = std(data.all{c},'omitnan'); 
    data.mn_theta(c) = mean(data.all{c},'omitnan'); 
    data.std_theta_with_outliers(c) = std(data.with_outliers{c},'omitnan'); 
    data.mn_theta_with_outliers(c) = mean(data.with_outliers{c},'omitnan'); 
end
% speed references:
data.references = 0.1:0.1:0.8;

% Use data from the 6th bee for showing attitude over time:
data.raw = Manip(6).Abeille;
