function [X_k1_k1, P_k1_k1, i_k1, K_k1] = kalman_filter_constant_alt_changing_att(X, P, Z, m, g, rate, kd, t1, t2, G, Q, R, flag)
% function [X_k1_k1, P_k1_k1, i_k1, K_k1] = kalman_filter_constant_alt_changing_att(X, P, Z, m, g, rate, kd, t1, t2, G, Q, R, flag)
%
% Extended Kalman Filter for constant height model with rates as control
% inputs
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

Nx = length(X);

% Prediction: odefcn_const_alt_changing_att(t, x, m, g, p, kd, xv)
X_k1_k =  X + odefcn_const_alt_changing_att(1, X, m, g, rate, kd, [0 0 0])*(t2-t1);

% get state variables:
v = X_k1_k(1); theta = X_k1_k(2);  z = X_k1_k(3);

% state transition matrix:
Fx = [-sign(v)*2*kd*v/m g/cos(theta)^2 0; 0 0 0; 0 0 0];    %%%%%%%%%

% Jacobian observation matrix:
if(length(Z) == 1)
    Hx = [-cos(theta)^2/z, (v*sin(2*theta))/ z, (v* cos(theta)^2)/z^2];   %%%%%%%%%
else
    Hx = [-cos(theta)^2/z, (v*sin(2*theta))/ z, (v* cos(theta)^2)/z^2; ...
        -sin(2*theta)/(2*z), -v*cos(2*theta)/z, v*sin(2*theta)/(2*z^2)];   %%%%%%%%%
end

% Discretize
[Phi_k1_k, Gamma_k1_k] = c2d(Fx, G, t2-t1);

% Covariance matrix of state prediction error
P_k1_k = Phi_k1_k*P*Phi_k1_k' + Gamma_k1_k*Q*Gamma_k1_k';

% Kalman gain
S_k = Hx*P_k1_k*Hx' + R;
K_k1 = P_k1_k*Hx' * pinv(S_k);

if(flag == 1)
    % Measurement update
    if(length(Z) == 1)
        Z_expected = [-v*cos(theta)*cos(theta)/z + rate];
    else
        Z_expected = [-v*cos(theta)*cos(theta)/z + rate; ...
            -v*sin(2*theta)/(2*z)];      % Innovation  %%%%%%%%%%
    end
    i_k1 = Z - Z_expected;      % Innovation  %%%%%%%%%%
    
    % Update the state:
    X_k1_k1 = X_k1_k + K_k1*(i_k1);
    
    % Covariance matrix of state estimation error
    P_k1_k1 = (eye(Nx) - K_k1*Hx)*P_k1_k*(eye(Nx) - K_k1*Hx)' + K_k1*R*K_k1'; % Joseph form of the covariance update equation
else
    X_k1_k1 = X_k1_k;
    P_k1_k1 = P_k1_k;
    i_k1 = 0;
end
