function [X_k1_k1, P_k1_k1, i_k1, K_k1] = kalman_filter_constant_alt_changing_att_insect(X, P, Z, m, g, rate, rate_head, kd, t1, t2, G, Q, R, flag)
% function [X_k1_k1, P_k1_k1, i_k1, K_k1] = kalman_filter_constant_alt_changing_att_insect(X, P, Z, m, g, rate, rate_head, kd, t1, t2, G, Q, R, flag)
%
% Extended Kalman Filter for constant height model with rates as control
% inputs, for the insect model with head and thorax.
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

Nx = length(X);

% Prediction: 
X_k1_k =  X + odefcn_const_alt_changing_att_insect(1, X, m, g, rate, rate_head, kd, [0 0 0 0])*(t2-t1);

v = X_k1_k(1); theta = X_k1_k(2);  theta_wings = X_k1_k(3); z = X_k1_k(4);

% state transition matrix:
Fx(1,:) = [ -kd/m, 0, g*(tan(theta_wings)^2 + 1), 0]; % linear drag model
Fx(2,:) = [     0, 0,                        0, 0];
Fx(3,:) = [     0, 0,                        0, 0];
Fx(4,:) = [     0, 0,                        0, 0];

% Jacobian observation matrix:
if(length(Z) == 2)
    Hx = [-cos(theta)^2/z, (v*sin(2*theta))/ z, 0, (v* cos(theta)^2)/z^2; ...
          0, 1, -1, 0];   %%%%%%%%%
else
    Hx = [-cos(theta)^2/z, (v*sin(2*theta))/ z, 0, (v* cos(theta)^2)/z^2; ...
        -sin(2*theta)/(2*z), -v*cos(2*theta)/z, 0, v*sin(2*theta)/(2*z^2); ...
        0, 1, -1, 0 ];   %%%%%%%%%
end

% Discretize
[Phi_k1_k, Gamma_k1_k] = c2d(Fx, G, t2-t1);

% Covariance matrix of state prediction error
P_k1_k = Phi_k1_k*P*Phi_k1_k' + Gamma_k1_k*Q*Gamma_k1_k';

% Kalman gain
S_k = Hx*P_k1_k*Hx' + R;
K_k1 = P_k1_k*Hx' * pinv(S_k);

if(flag == 1)
    % Measurement update
    if(length(Z) == 2)
        Z_expected = [-v*cos(theta)*cos(theta)/z + rate; ...
                        theta - theta_wings];
    else
        Z_expected = [-v*cos(theta)*cos(theta)/z + rate; ...
                      -v*sin(2*theta)/(2*z); ...
                      theta - theta_wings];      % Innovation  %%%%%%%%%%
    end
    i_k1 = Z - Z_expected;      % Innovation  %%%%%%%%%%
    
    % Update the state:
    X_k1_k1 = X_k1_k + K_k1*(i_k1);
    
    % Covariance matrix of state estimation error
    P_k1_k1 = (eye(Nx) - K_k1*Hx)*P_k1_k*(eye(Nx) - K_k1*Hx)' + K_k1*R*K_k1'; % Joseph form of the covariance update equation
    % fprintf('Trace: eKJac P ekJacT = %f, KRKT = %f\n', trace((eye(Nx) - K_k1*Hx)*P_k1_k*(eye(Nx) - K_k1*Hx)'), trace(K_k1*R*K_k1'));
else
    X_k1_k1 = X_k1_k;
    P_k1_k1 = P_k1_k;
    i_k1 = 0;
end
