function observability_analysis()
% function observability_analysis()
%
% Runs all scripts related to the observability analysis in the article
% below. 
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

% Analyze local, weak observability for all models in the article (SI):
n_cases = 7;
for CASE = 1:n_cases
    fprintf('***** CASE %d / %d *****\n', CASE, n_cases);
    sym_observability(CASE);
end

% Local observability analysis:
local_observability_analysis(1); % random points
local_observability_analysis(2); % all points on a grid

% Make plots for the observability degree (Fig. 1d and e in the main text):

% (1): get a trajectory when measuring rates and when not measuring rates, 
% resulting in results_hover.mat and results_hover_rate.mat:
RATE = false;
fprintf('Generating trajectory for system without rate measurements.\n');
trajectory_for_Fig1(RATE);
RATE = true;
fprintf('Generating trajectory for system with rate measurements.\n');
trajectory_for_Fig1(RATE);

% (2): make the plots:
MOMENT_MODEL = true;
DIVERGENCE = false;
DRAG = false;
PLOT_TRAJECTORY = true;

% Constant height, varying attitude model with moments as actions:
% Measuring rate:
MEASURE_RATE = true;
plot_observability_vs_states(MOMENT_MODEL, MEASURE_RATE, DIVERGENCE, DRAG, PLOT_TRAJECTORY, 'With rate measurements');
% Not measuring rate:
MEASURE_RATE = false;
plot_observability_vs_states(MOMENT_MODEL, MEASURE_RATE, DIVERGENCE, DRAG, PLOT_TRAJECTORY, 'Without rate measurements');

% Velocity hypothesis (Fig. 2g of Extended Data):
MOMENT_MODEL = false;
MEASURE_RATE = true;
DIVERGENCE = true;
DRAG = true;
PLOT_TRAJECTORY = false;
plot_observability_vs_states(MOMENT_MODEL, MEASURE_RATE, DIVERGENCE, DRAG, PLOT_TRAJECTORY);