function dydt = odefcn_const_alt_changing_att(t, x, m, g, p, kd, xv)
% function dydt = odefcn_const_alt_changing_att(t, x, m, g, p, kd, xv)
%
% System Dynamics (3 DoF quadcopter dynamics)
% x is the true state [v; phi; z]
% m is the mass
% g is gravity acceleration
% p is the rate command
% kd is a linear drag term
% xv is the noise vector in various state changes
%
% f = [(g*tan(phi)); p; 0];   
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

dydt = zeros(size(x));
dydt(1) = g*tan(x(2)) - sign(x(1)) * kd*x(1)^2/m + xv(1); % with drag
dydt(2) = p + xv(2);
dydt(3) = xv(3);

end