function dydt = odefcn_const_alt_changing_att_insect(t, x, m, g, p, p_head, kd, xv)
% function dydt = odefcn_const_alt_changing_att_insect(t, x, m, g, p, p_head, kd, xv)
%
% System Dynamics (3 DoF quadcopter dynamics)
% x is the true state [v; phi; phi_wings; z]
% m is the mass
% g is gravity acceleration
% p is the rate command of the thorax
% p_head is the rate command of the head 
% kd is a linear drag term 
% xv is the noise vector in various state changes
%
% f = [(g*tan(phi_wings)); p_head; p; 0];   
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

dydt = zeros(size(x));
dydt(1) = g*tan(x(3)) - sign(x(1)) * kd*x(1)^2/m + xv(1); % with drag
dydt(2) = p_head + xv(2);
dydt(3) = p + xv(3);
dydt(4) = xv(4);

end