function dydt = odefcn_const_alt_changing_att_moment(t, x, m, g, M, I, kd, xv)
% function dydt = odefcn_const_alt_changing_att_moment(t, x, m, g, M, I, kd, xv)
%
% Simulate system Dynamics (3 DoF quadcopter dynamics)
%
% x is the true state [v; theta; theta dot; z]
% m is the mass
% g is gravity acceleration
% M is the moment command
% I is the moment of inertia
% kd is a linear drag term
% xv is the noise vector in various state changes
% f = [(g*tan(phi)); p; M/I; 0];   % State Derivative
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

dydt = zeros(size(x));
dydt(1) = g*tan(x(2)) - sign(x(1)) * kd*x(1)^2/m + xv(1); % with drag
dydt(2) = x(3) + xv(2);
dydt(3) = M/I+xv(3);
dydt(4) = xv(4);

end