function plot_results_performance_chart(results, xtitle, ytitle, xticks)
% function plot_results_performance_chart(results, xtitle, ytitle, xticks)
%
% Plot the results for the performance charts when varying, e.g., sensor
% and actuation noise. 
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

if(~exist('results', 'var') || isempty(results))
    load('results_noise_performance');
end
if(~exist('xtitle', 'var') || isempty(xtitle))
    xtitle = 'Noise settings';
end
if(~exist('ytitle', 'var') || isempty(ytitle))
    ytitle = 'Optical flow frequency [Hz]';
end
if(~exist('xticks', 'var') || isempty(xticks))
    n_settings = length(results.noise_settings);
    xticks = {};
    for s = 1:n_settings
        if(results.noise_settings(1,s) == 0)
            xticks{s} = ['\sigma_{OF}=' num2str(results.noise_settings(2, s))];
        else
            xticks{s} = ['\sigma_M=' num2str(results.noise_settings(1, s))];
        end
    end
end

n_settings = length(results.settings);
n_OFdts = length(results.OFdts);
% When to make the squares red:
threshold_MAE = 0.065;
overshoot_threshold = 25;

% color spaces:
GYR_08 = 0.8 * [[linspace(0, 1, 128)';  ones(128, 1)], [ones(128,1); linspace(1, 0, 128)'], zeros(256, 1)];

% plot the results:
figure()
set(gcf, 'color', 'w')
ax = gca;
ax.TickLabelInterpreter = 'latex';
colormap(GYR_08);
MAE = results.MAE;
inds = find(results.OP > overshoot_threshold);
MAE(inds) = threshold_MAE;
imagesc(MAE);
set(gca, 'XTick', 1:n_settings, 'XTickLabel', xticks);
set(gca, 'YTick', 1:n_OFdts, 'YTickLabel', round(1./results.OFdts));
xlabel(xtitle, 'Interpreter', 'latex');
ylabel(ytitle, 'Interpreter', 'latex');
title('Mean absolute error', 'Interpreter', 'latex');
colorbar;
caxis([0, threshold_MAE]);
xtickangle(45);
set(gca, 'fontsize', 14);
