function run_sim_constant_height_rate()
% function run_sim_constant_height_rate()
%
% Run experiments with various types of noise to check the theoretical
% proof on stability despite unobservability.
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

params = set_standard_params_simulate_controller_constant_altitude();

% External disturbances:
NO_DISTURBANCE = 0;
THRUST_DISTURBANCE = 1;
HORIZONTAL_DISTURBANCE = 2;
MALICIOUS_V0 = 3;
params.external_disturbance = NO_DISTURBANCE;

% Control gains:
params.K_v = 5 * pi/180; % velocity gain
params.K_i = 0.25 * params.K_v; % incremental gain for OF control
params.K_z_factor = 3;

%  Initial state:
params.initial_state = [1, 0*pi/180, 1]';   %[v, theta, z]
params.initial_estimated_state = params.initial_state;

rng(2021);

% no noise, no disturbances, no problem:
[metrics, results] = simulate_controller_constant_altitude_changing_attitude(params, 'No noise, no disturbances');

% Sensor noise:
params.sigma_OF = 0.02; % ventral flow noise
[metrics, results] = simulate_controller_constant_altitude_changing_attitude(params, 'Sensor noise');
params.sigma_OF = 0;

% Actuation noise:
params.sigma_rate = deg2rad(1.0); % rate input to system noise
[metrics, results] = simulate_controller_constant_altitude_changing_attitude(params, 'Actuation noise');
params.sigma_rate = 0;

% Disturbances:
params.external_disturbance = HORIZONTAL_DISTURBANCE;
params.sigma_T = 0.1;
[metrics, results] = simulate_controller_constant_altitude_changing_attitude(params, 'Disturbances');
params.external_disturbance = NO_DISTURBANCE;

% Malicious disturbances
params.external_disturbance = MALICIOUS_V0;
params.sigma_T = 0.1;
[metrics, results] = simulate_controller_constant_altitude_changing_attitude(params, 'Malicious disturbances');
params.sigma_T = 0;