function run_sim_insect_model()
% function run_sim_insect_model()
%
% Makes the plots for verifying the hypothesis that at higher flight
% speeds, the attitude oscillates less.
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

params = set_standard_params_simulate_controller_constant_altitude(false, false, true);

params.VIDEO = false;
params.video_dt = 0.1;
params.save_video = false;

params.DIVERGENCE = false;

params.T = 10;     % max time

% noise:
params.OFdt = 1/30;
params.sigma_OF = 0.02;
params.delay_OF = 0.033;
params.sigma_rate = 0.005;
params.sigma_T = 0.05; 
params.sigma_head_thorax = deg2rad(0.5); % measurement noise of angle between head and body
% delays, all in seconds:
params.delay_rate = 0.01;      % delay in rate input to system
params.delay_rate_k = 0.01;   % delay in rate input to kalman filter
params.delay_T = 0.01;      % delay in thrust input to system
params.delay_T_k = 0.01;   % delay in thrust input to kalman filter
params.delay_ht = 0.01;    % delay in head-thorax measurement

% External disturbances:
NO_DISTURBANCE = 0;
THRUST_DISTURBANCE = 1;
HORIZONTAL_DISTURBANCE = 2;
MALICIOUS_V0 = 3;
params.external_disturbance = HORIZONTAL_DISTURBANCE; 


params.control_ref = 0.8; 

params.initial_state = [0.5, 0*pi/180, 0*pi/180, 1]';
params.initial_estimated_state = params.initial_state;

params.K_head = 0.1; % head attitude gain
params.kd = 3.0;
params.WING_DRAG = true; % little influence when angles not too big
params.K_v = 50*pi/180;
params.K_theta = 1.0; % if too high, estimates no longer equal to true states...
params.alpha = 0.0; % 0.0 = no actuator delay, 1.0 = command has no effect
params.delay_rate = 0.01; % delay in rate input to system
params.sigma_OF = 0.06;

rng(2021)

[metrics, results] = simulate_controller_constant_altitude_changing_attitude_insect(params);

fprintf('Control OF ref = %f\n', params.control_ref);
fprintf('Std body attitude: %f\n', std(rad2deg(results.state(3,round(end/2):end))));
mae  = mean(abs(results.estimated_state(:, round(end/2):end) - results.state(:, round(end/2):end)), 2);
fprintf('Estimation error body attitude: %f\n', rad2deg(mae(3)));
