function run_simulations()
% function run_simulations()
%
% Runs all scripts related to the simulations used in the article below. 
%
% Article: 
% Accommodating unobservability to control flight attitude with optic flow
% G.C.H.E. de Croon, J.J.G. Dupeyroux, C. De Wagter, A. Chatterjee, D.A. Olejnik, F. Ruffier
%
% Code by:
% Abhishek Chatterjee | abhishek.chaterjee002@gmail.com
% Guido de Croon | g.c.h.e.decroon@tudelft.nl

% Control performance plots without and with rate measurements (Figure 1)
if(~exist('results_noise_performance.mat', 'file'))
    N = 10;
    RATE_MEASUREMENT = false;
    chart_performance_constant_altitude_changing_attitude_moment(N, false, RATE_MEASUREMENT);
    RATE_MEASUREMENT = true;
    chart_performance_constant_altitude_changing_attitude_moment(N, false, RATE_MEASUREMENT);
else
    load('results_noise_performance.mat');
    plot_results_performance_chart(results);
    load('results_noise_performance_rate.mat');
    plot_results_performance_chart(results);
end

% Investigate effect of residual / active oscillations on observability (Figure 3):
investigate_active_oscillations();

% Single run of the insect model (Extended Data figure 10)
run_sim_insect_model();

% Verify hypothesis faster flight (Extended Data figure 2)
N = 30;
if(~exist('results_speed_hypothesis.mat', 'file'))
    verify_hypothesis_faster_flight_insect(N, false);
    verify_hypothesis_faster_flight_insect(N, true);
end
load('results_speed_hypothesis_GT.mat');
results_GT = results;
load('results_speed_hypothesis.mat');
plots_hypothesis_faster_flight(results, results_GT)

% Verify the theoretical proof with simulation experiments (Extended Data Figure 7 and 8):
run_sim_constant_height_rate();
